@@ -4,3 +4,6 @@ from .mounted_volume import *
 from .partition import *
 from .simple import *
 from .linux_device import *
+from .logical_volume import *
+from .physical_volume import *
+from .volume_group import *
