@@ -24,9 +24,28 @@ class LinuxDeviceForm(NetBoxModelForm):
         fields = (
             "device",
             "type",
-            "description",
         )
 
+    #def save(self, *args, **kwargs):
+    #    new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
+    #    device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
+    #    device_name = device_name_prefix + str(new_partition_count)
+
+
+     #   return linux_device
+        """
+        project_owner_pk = ContactRole.objects.get(name='Project Owner').pk
+        ocp_project_type_pk = ContentType.objects.get(app_label='ocp_project_plugin', model='ocpproject').pk
+
+        count_assignment = ContactAssignment.objects.filter(object_id=self.pk).count()
+        if count_assignment == 0:
+            ContactAssignment.objects.create(object_id=self.pk,
+                                             contact_id=self.project_owner.pk,
+                                             content_type_id=ocp_project_type_pk,
+                                             role_id=project_owner_pk)
+
+        """
+
 
 class LinuxDeviceFilterForm(NetBoxModelFilterSetForm):
 
@@ -48,7 +67,6 @@ class LinuxDeviceImportForm(NetBoxModelImportForm):
         fields = (
             "device",
             "type",
-            "description",
         )
 
 
@@ -63,12 +81,10 @@ class LinuxDeviceBulkEditForm(NetBoxModelBulkEditForm):
         required=False,
         label="Type",
     )
-    description = CharField(max_length=255, required=False)
 
     fieldsets = (
         (
             None,
-            ("device", "type", "description"),
+            ("device", "type"),
         ),
     )
-    nullable_fields = ["description"]
