@@ -1,8 +1,11 @@
+from django.contrib.contenttypes.fields import GenericForeignKey
+from django.contrib.contenttypes.models import ContentType
 from django.db import models
-from django.db.models import Sum
+from django.db.models import Sum, CharField
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
+from netbox_storage.choices import OSTypeChoices
 
 
 class Filesystem(NetBoxModel):
@@ -15,16 +18,16 @@ class Filesystem(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["filesystem", "description"]
+    clone_fields = ['filesystem', 'description']
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:filesystem", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:filesystem', kwargs={'pk': self.pk})
 
     def __str__(self):
-        return f"{self.filesystem}"
+        return f'{self.filesystem}'
 
     class Meta:
-        ordering = ("filesystem", "description")
+        ordering = ('filesystem', 'description')
 
 
 class Drive(NetBoxModel):
@@ -34,7 +37,7 @@ class Drive(NetBoxModel):
         related_name='cluster_drive',
     )
     size = models.FloatField(
-        verbose_name="Size (GB)"
+        verbose_name='Size (GB)'
     )
     identifier = models.CharField(
         max_length=255,
@@ -44,28 +47,28 @@ class Drive(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["cluster", "size", "identifier", "description"]
+    clone_fields = ['cluster', 'size', 'identifier', 'description']
 
     prerequisite_models = (
         'virtualization.Cluster',
     )
 
     class Meta:
-        ordering = ["size"]
+        ordering = ['size']
 
     def __str__(self):
-        return f"{self.identifier}-{self.size}MB-{self.cluster}"
+        return f'{self.identifier}-{self.size}MB-{self.cluster}'
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:drive', kwargs={'pk': self.pk})
 
     def save(self, *args, **kwargs):
         is_already_implemented = Drive.objects.filter(id=self.pk).count()
         if is_already_implemented == 0:
             number_of_hard_drives = Drive.objects.all().\
-                order_by("created").count()
+                order_by('created').count()
 
-            self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
+            self.identifier = f'Hard Drive {number_of_hard_drives + 1}'
 
         super(Drive, self).save(*args, **kwargs)
 
@@ -77,14 +80,14 @@ class Drive(NetBoxModel):
         return Partition.objects.filter(drive=self).count()
 
     def device_name(self):
-        return f"/dev/sd{chr(ord('`') + int(self.identifier[-1]))}"
+        return f'/dev/sd{chr(ord("`") + int(self.identifier[-1]))}'
 
     def physicalvolumes_in_drive_count(self):
         return PhysicalVolume.objects.filter(drive=self).count()
 
     def left_free_space(self):
-        current_partition_allocated_space = Partition.objects.filter(drive=self).aggregate(sum=Sum("size")).get(
-            "sum") or 0
+        current_partition_allocated_space = Partition.objects.filter(drive=self).aggregate(sum=Sum('size')).get(
+            'sum') or 0
         return self.size - current_partition_allocated_space
 
 
@@ -95,8 +98,8 @@ class MountedVolume(NetBoxModel):
     fs_type = models.ForeignKey(
         Filesystem,
         on_delete=models.CASCADE,
-        related_name="fs_mounted_volume",
-        verbose_name="Filesystem",
+        related_name='fs_mounted_volume',
+        verbose_name='Filesystem',
     )
     options = models.CharField(
         max_length=255,
@@ -108,20 +111,20 @@ class MountedVolume(NetBoxModel):
     )
 
     clone_fields = [
-        "mount_point",
-        "fs_type",
-        "options",
-        "description",
+        'mount_point',
+        'fs_type',
+        'options',
+        'description',
     ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:mountedvolume', kwargs={'pk': self.pk})
 
     def __str__(self):
-        return f"Filesystem Table Entry: mounted to {self.mount_point}"
+        return f'Filesystem Table Entry: mounted to {self.mount_point}'
 
     class Meta:
-        ordering = ("mount_point", "fs_type", "options", "description")
+        ordering = ('mount_point', 'fs_type', 'options', 'description')
 
 
 class LinuxDevice(NetBoxModel):
@@ -131,24 +134,23 @@ class LinuxDevice(NetBoxModel):
     type = models.CharField(
         max_length=255,
     )
-    mounted_volume = models.ForeignKey(
-        MountedVolume,
-        on_delete=models.CASCADE,
-        related_name='mounted_volume_device',
-        blank=True
+    content_type = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE
     )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
+    object_id = models.PositiveBigIntegerField()
+    object = GenericForeignKey(
+        ct_field='content_type',
+        fk_field='object_id'
     )
 
-    clone_fields = ["device", "type", "description"]
+    clone_fields = ['device', 'type', 'content_type', 'object_id']
 
     def __str__(self):
         return f'{self.device}'
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:linuxdevice", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:linuxdevice', kwargs={'pk': self.pk})
 
 
 class Partition(NetBoxModel):
@@ -163,7 +165,7 @@ class Partition(NetBoxModel):
         related_name='device_partition',
     )
     size = models.FloatField(
-        verbose_name="Size (GB)"
+        verbose_name='Size (GB)'
     )
     type = models.CharField(
         max_length=255,
@@ -173,33 +175,33 @@ class Partition(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["drive", "device", "size", "type", "description"]
+    clone_fields = ['drive', 'device', 'size', 'type', 'description']
 
     prerequisite_models = (
         'netbox_storage.Drive',
     )
 
     class Meta:
-        ordering = ["size"]
+        ordering = ['size']
 
     def __str__(self):
         return f'{self.device}'
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:partition", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:partition', kwargs={'pk': self.pk})
 
     @property
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/partition/'
 
-    """def clean(self, *args, **kwargs):
-        total_allocated_space = Partition.objects.filter(drive=self.drive).aggregate(sum=Sum("size")).get("sum") or 0
+    '''def clean(self, *args, **kwargs):
+        total_allocated_space = Partition.objects.filter(drive=self.drive).aggregate(sum=Sum('size')).get('sum') or 0
         current_partition_size = Partition.objects.filter(drive=self.drive, id=self.pk) \
-                                     .aggregate(sum=Sum("size")).get("sum") or 0
+                                     .aggregate(sum=Sum('size')).get('sum') or 0
         if self.size is None:
             raise ValidationError(
                 {
-                    "size": f"The Value for Size must be greater than 0"
+                    'size': f'The Value for Size must be greater than 0'
                 }
             )
         diff_to_allocated_space = self.size - current_partition_size
@@ -207,22 +209,22 @@ class Partition(NetBoxModel):
             if total_allocated_space == self.drive.size:
                 raise ValidationError(
                     {
-                        "size": f"The maximum Space of the hard drive was already allocated."
+                        'size': f'The maximum Space of the hard drive was already allocated.'
                     }
                 )
             if self.size > self.drive.size:
                 raise ValidationError(
                     {
-                        "size": f"The size of the Partition is bigger than the size of the Hard Drive."
+                        'size': f'The size of the Partition is bigger than the size of the Hard Drive.'
                     }
                 )
             if total_allocated_space + self.size > self.drive.size:
                 raise ValidationError(
                     {
-                        "size": f"The size of the Partition is bigger than the size of the Hard Drive."
+                        'size': f'The size of the Partition is bigger than the size of the Hard Drive.'
                     }
                 )
-"""
+'''
     def get_affiliated_physical_volume(self):
         return PhysicalVolume.objects.filter(partition=self).first()
 
@@ -237,18 +239,18 @@ class VolumeGroup(NetBoxModel):
     )
 
     clone_fields = [
-        "vg_name",
-        "description",
+        'vg_name',
+        'description',
     ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:volumegroup", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:volumegroup', kwargs={'pk': self.pk})
 
     def __str__(self):
         return self.vg_name
 
     class Meta:
-        ordering = ("vg_name", "description")
+        ordering = ('vg_name', 'description')
 
     def physical_volume_count(self):
         return PhysicalVolume.objects.filter(vg=self).count()
@@ -280,19 +282,19 @@ class PhysicalVolume(NetBoxModel):
     )
 
     clone_fields = [
-        "device",
-        "vg",
-        "description",
+        'device',
+        'vg',
+        'description',
     ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:physicalvolume', kwargs={'pk': self.pk})
 
     def __str__(self):
-        return f"{self.device}"
+        return f'{self.device}'
 
     class Meta:
-        ordering = ("device", "description")
+        ordering = ('device', 'description')
 
 
 class LogicalVolume(NetBoxModel):
@@ -301,7 +303,7 @@ class LogicalVolume(NetBoxModel):
         max_length=255,
     )
     size = models.FloatField(
-        verbose_name="Size (GB)"
+        verbose_name='Size (GB)'
     )
     device = models.ForeignKey(
         LinuxDevice,
@@ -314,21 +316,21 @@ class LogicalVolume(NetBoxModel):
     )
 
     clone_fields = [
-        "vg",
-        "lv_name",
-        "size",
-        "device",
-        "description",
+        'vg',
+        'lv_name',
+        'size',
+        'device',
+        'description',
     ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:logicalvolume", kwargs={"pk": self.pk})
+        return reverse('plugins:netbox_storage:logicalvolume', kwargs={'pk': self.pk})
 
     def __str__(self):
         return self.lv_name
 
     class Meta:
-        ordering = ("lv_name", "description")
+        ordering = ('lv_name', 'description')
 
 
 class StorageConfigurationDrive(NetBoxModel):
@@ -344,15 +346,15 @@ class StorageConfigurationDrive(NetBoxModel):
     )
 
     clone_fields = [
-        "virtual_machine",
-        "drive"
+        'virtual_machine',
+        'drive',
     ]
 
     class Meta:
-        ordering = ["virtual_machine", "drive"]
+        ordering = ['virtual_machine', 'drive']
 
     def __str__(self):
-        return f"Storage Configuration of the VM {self.virtual_machine}"
+        return f'Storage Configuration of the VM {self.virtual_machine}'
 
 
 class TemplateConfigurationDrive(NetBoxModel):
@@ -368,15 +370,15 @@ class TemplateConfigurationDrive(NetBoxModel):
     )
 
     clone_fields = [
-        "platform",
-        "drive"
+        'platform',
+        'drive',
     ]
 
     class Meta:
-        ordering = ["platform", "drive"]
+        ordering = ['platform', 'drive']
 
     # def get_absolute_url(self):
-    #     return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
+    #     return reverse('plugins:netbox_storage:storageconfiguration', kwargs={'pk': self.pk})
 
     def __str__(self):
-        return f"Template Configuration of the Platform {self.platform}"
+        return f'Template Configuration of the Platform {self.platform}'
