@@ -25,13 +25,9 @@ class LinuxDeviceTable(NetBoxTable):
             "pk",
             "device",
             "type",
-            "mounted_volume",
-            "description",
         )
         default_columns = (
             "pk",
             "device",
             "type",
-            "mounted_volume",
-            "description",
         )
