@@ -14,10 +14,6 @@ class MountedVolumeTable(NetBoxTable):
         linkify=True,
         verbose_name="Filesystem"
     )
-    device = tables.Column(
-        linkify=True,
-        verbose_name="Partition"
-    )
     mount_point = tables.Column(
         linkify=True,
         verbose_name="Mount point"
@@ -27,14 +23,12 @@ class MountedVolumeTable(NetBoxTable):
         model = MountedVolume
         fields = (
             "pk",
-            "device",
             "mount_point",
             "fs_type",
             "options",
             "description",
         )
         default_columns = (
-            "device",
             "mount_point",
             "fs_type",
             "options",
